@@ -2,7 +2,7 @@
 #
 # Copyright (C) 2000-2003 the xine project
 #
-# This file is part of xine, a free video player.
+# This file is part of xine, a unix video player.
 # 
 # xine is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,9 +16,9 @@
 # 
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
 #
-# $Id: autogen.sh,v 1.9 2004/01/01 18:11:55 valtri Exp $
+# $Id: autogen.sh,v 1.12 2006-02-21 19:06:09 dsalt Exp $
 #
 # Maintained by Stephen Torri <storri@users.sourceforge.net>
 #
@@ -106,13 +106,14 @@ run_autoconf () {
 #--------------------
 # LIBTOOL
 #-------------------
-detect_libtool() {
-  set -- `type libtool 2>/dev/null`
+try_libtool_executable() {
+  libtool=$1
+  set -- `type $libtool 2>/dev/null`
   RETVAL=$?
   NUM_RESULT=$#
   RESULT_FILE=$3
   if [ $RETVAL -eq 0 -a $NUM_RESULT -eq 3 -a -f "$RESULT_FILE" ]; then
-    LT="`libtool --version | awk '{ print $4 }' | sed -e 's/[a-zA-Z\ \.\(\)\-\;]//g'`"
+    LT="`$libtool --version | awk '{ print $4 }' | sed -e 's/[a-zA-Z\ \.\(\)\-\;]//g'`"
     LIBTOOL_MIN="`echo $LIBTOOL_MIN | sed -e 's/[a-zA-Z\ \.\(\)\-]//g'`"
     if test $LT -lt 100 ; then
       LT=`expr $LT \* 10`
@@ -120,12 +121,21 @@ detect_libtool() {
     if [ `expr $LT` -ge $LIBTOOL_MIN ]; then
       libtool_ok=yes
     fi
-  else
-    echo
-    echo "**Error**: You must have \`libtool' >= $LIBTOOL_MIN installed to" 
-    echo "           compile $PROG. Download the appropriate package"
-    echo "           for your distribution or source from ftp.gnu.org."
-    exit 1
+  fi
+}
+
+detect_libtool() {
+  # try glibtool first, then libtool
+  try_libtool_executable 'glibtool'
+  if [ "x$libtool_ok" != "xyes" ]; then
+    try_libtool_executable 'libtool'
+    if [ "x$libtool_ok" != "xyes" ]; then
+      echo
+      echo "**Error**: You must have \`libtool' >= $LIBTOOL_MIN installed to" 
+      echo "           compile $PROG. Download the appropriate package"
+      echo "           for your distribution or source from ftp.gnu.org."
+      exit 1
+    fi
   fi
 }
 
@@ -138,7 +148,7 @@ run_libtoolize() {
   fi
 
   echo $_echo_n " + Running libtoolize: $_echo_c";
-    libtoolize --force --copy >/dev/null 2>&1;
+    "${libtool}ize" --force --copy >/dev/null 2>&1;
   echo "done."
 }
 
@@ -224,9 +234,9 @@ run_aclocal () {
   fi
   
   echo $_echo_n " + Running aclocal: $_echo_c"
-  aclocalinclude=`xine-config --acflags`
+  aclocalinclude=`if [ ! -z "$XINE_CONFIG" ]; then $XINE_CONFIG --acflags; else xine-config --acflags; fi`
 
-  aclocal $aclocalinclude -I m4
+  aclocal -I m4 $aclocalinclude
   echo "done." 
 }
 
@@ -287,6 +297,6 @@ case "$1" in
     run_autoheader
     run_automake
     run_autoconf
-    run_configure $@
+    run_configure "$@"
     ;;
 esac
