@@ -15,9 +15,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
  *
- * $Id: plugin.c,v 1.28 2004/11/11 01:22:52 dsalt Exp $
+ * $Id: plugin.c,v 1.33 2006-02-21 19:06:11 dsalt Exp $
  *
  * xine plugin for mozilla
  *
@@ -157,7 +157,7 @@ char *NPP_GetMIMEDescription(void) {
          "video/x-msvideo: avi: AVI animation;"
          "application/x-mplayer2: asf,asx,asp: mplayer2;"
          "video/x-ms-asf-plugin: asf,asx,asp: mms animation;"
-         "audio/x-pn-realaudio-plugin: rpm: Real audio;"
+         /*"audio/x-pn-realaudio-plugin: rpm: Real audio;"*/
          "audio/x-ogg: ogg,ogm: OGG Media;"
          "audio/x-scpls: pls: MPEG audio"
 	 ;
@@ -206,6 +206,7 @@ void NPP_Shutdown(void) {
  xprintf("NPP_Shutdown:\n");
 }
 
+/*
 static void print_status (plugin_instance_t *this, const char *format, ...) {
 
   va_list argp;
@@ -220,6 +221,7 @@ static void print_status (plugin_instance_t *this, const char *format, ...) {
   paint_it (this);
 #endif
 }
+*/
 
 /* fork2() -- like fork, but the new process is immediately orphaned
  *            (won't leave a zombie when it exits)
@@ -294,13 +296,13 @@ static void launch_gxine (plugin_instance_t *this) {
     snprintf(executable, 4096, "%s/gxine", GXINE_BINDIR);
 
     if (this->emu_mode == EMU_MPLAYER)
-      snprintf(arg, 4096, "mms%s", globals.url);
+      snprintf(arg, sizeof (arg), "mms%s", globals.url);
     else
-      strncpy(arg, globals.url, 4096);
+      snprintf(arg, sizeof (arg), "%s", globals.url);
 
     xprintf ("launch_gxine: exe = %s, arg = %s\n", executable, arg);
 
-    if (execlp("gxine", executable, arg, NULL) == -1) {
+    if (execlp("gxine", executable, "-a", arg, NULL) == -1) {
        perror("Error while launching gxine");
        _exit(0);
     }
@@ -326,7 +328,10 @@ static void launch_gxine (plugin_instance_t *this) {
 static void got_url (const char *url_) {
 
   if (strstr (url_, ":/"))
+  {
+    free (globals.url);
     globals.url = strdup (url_);
+  }
   else
     xprintf ("got_url: ignoring this url (%s) because it is a relative one.\n",
 	     url_);
@@ -362,10 +367,9 @@ NPError NPP_New(NPMIMEType pluginType, NPP instance,
 
     for (i=0; i<argc; i++) {
 
-     xprintf ("plugin: argument '%s'='%s'\n",
-	      argn[i], argv[i]);
+      xprintf ("plugin: argument '%s'='%s'\n", argn[i], argv[i]);
 
-      if (!strncmp (argn[i], "type", 4)) {
+      if (!strcasecmp (argn[i], "type")) {
 	if (!strncmp (argv[i], "video/x-ms-asf-plugin", 21)) {
 	  xprintf ("plugin: switching to mms_mode\n");
 	  this->emu_mode = EMU_MPLAYER;
@@ -379,7 +383,7 @@ NPError NPP_New(NPMIMEType pluginType, NPP instance,
 	  xprintf ("plugin: switching to real player emulation mode\n");
 	  this->emu_mode = EMU_REAL;
 	}
-      } else if (!strcmp (argn[i], "name")) {
+      } else if (!strcasecmp (argn[i], "name")) {
 	if (!strcmp (argv[i], "nsplay")) {
 	  xprintf ("plugin: switching to mms_mode\n");
 	  this->emu_mode = EMU_MPLAYER;
@@ -424,11 +428,13 @@ static void play_cb (Widget w, XtPointer client_data, XtPointer call_data) {
   launch_gxine (this);
 }
 
+/*
 static void close_cb (Widget w, XtPointer client_data, XtPointer call_data) {
   Widget shell = (Widget) client_data;
 
   XtPopdown (shell);
 }
+*/
 
 #ifdef URLBOX
 static void url_cb (Widget w, XtPointer client_data, XtPointer call_data) {
@@ -568,6 +574,12 @@ NPError NPP_Destroy(NPP instance, NPSavedData** save) {
 
   }
 
+  if (globals.url)
+  {
+    free (globals.url);
+    globals.url = NULL;
+  }
+
   globals.gxine_started = FALSE;
 
   xprintf("NPP_Destroy: closed.\n");
