@@ -13,16 +13,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: client.c,v 1.4.2.1 2005/08/01 22:47:17 dsalt Exp $
+ * $Id: client.c,v 1.11 2006/03/27 22:48:57 dsalt Exp $
  *
  * gxine Javascript client
  */
 
 #include "config.h"
 #include "i18n.h"
+#include "console_output.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,10 +46,13 @@ static void sigpipe (int sig)
   signal (SIGPIPE, sigpipe);
 }
 
-int main (int argc, char **argv) {
-
+int main (int argc, char **argv)
+{
   int                fd, tfd;
-  struct sockaddr_un cli_adr, serv_adr;
+  union {
+    struct sockaddr_un u;
+    struct sockaddr s;
+  } cli_adr = { .u = {0} }, serv_adr = { .u = {0} };
   int                length = sizeof(struct sockaddr_un);
   char               filename [1024];
   char              *tstr;
@@ -56,16 +60,23 @@ int main (int argc, char **argv) {
 
   signal (SIGPIPE, sigpipe);
 
-  /* server filename */
-  snprintf (filename, 1024, SOCKET_FILENAME, getenv ("HOME")); 
+#ifdef ENABLE_NLS
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  textdomain (PACKAGE);
+#endif
 
-  printf (_("Connecting to %s...\n"), filename);
+  console_output_init ();
+
+  /* server filename */
+  snprintf (filename, sizeof (filename), SOCKET_FILENAME, getenv ("HOME")); 
+
+  g_print (_("Connecting to %s...\n"), filename);
 
   fd = socket (AF_UNIX, SOCK_STREAM, 0);
 
   /* initialize the client address structure */
-  memset (&cli_adr, 0, sizeof (cli_adr));
-  cli_adr.sun_family = AF_UNIX;
+  cli_adr.u.sun_family = AF_UNIX;
   tstr = strdup ("/tmp/gxine_XXXXXX");
   tfd = mkstemp (tstr);
   if (tfd < 0)
@@ -74,38 +85,37 @@ int main (int argc, char **argv) {
     exit (EXIT_FAILURE);
   }
   close (tfd);
-  strncpy (cli_adr.sun_path, tstr, sizeof (cli_adr.sun_path) - 1);
+  strncpy (cli_adr.u.sun_path, tstr, sizeof (cli_adr.u.sun_path) - 1);
 
   unlink (tstr);
 
   /* bind the socket to the client's address */
-  if (bind (fd, (struct sockaddr*) &cli_adr, length) < 0) {
+  if (bind (fd, &cli_adr.s, length) < 0) {
     perror ("bind");
     exit (EXIT_FAILURE);
   }
 
   /* initialize the server address structure */
-  memset(&serv_adr, 0, sizeof(serv_adr));
-  serv_adr.sun_family = AF_UNIX;
-  strcpy (serv_adr.sun_path, filename);
+  serv_adr.u.sun_family = AF_UNIX;
+  strcpy (serv_adr.u.sun_path, filename);
 
-  if (connect (fd, (struct sockaddr *) &serv_adr, sizeof (serv_adr)) < 0) {
+  if (connect (fd, &serv_adr.s, sizeof (serv_adr)) < 0) {
     perror ("connect");
     exit (EXIT_FAILURE);
   }
   
-  printf (_("Connected.\n"));
+  g_print (_("Connected.\n"));
 
   if (argc>1) {
 
     /* noninteractive */
 
-    printf (_("Sending command\n"));
+    g_print (_("Sending command\n"));
 
     write (fd, argv[1], strlen(argv[1]));
     write (fd, "\n", 1);
 
-    printf (_("Done.\n"));
+    g_print (_("Done.\n"));
 
   } else {
     /* interactive mode */
@@ -132,8 +142,18 @@ int main (int argc, char **argv) {
       }
 
       if (FD_ISSET (fd, &rset)) {
-	if (read (fd, buf, 1)==1)
+	switch (read (fd, buf, 1))
+	{
+	case EOF:
+	  perror ("client: output: ");
+	  break;
+	case 0:
+	  done = 1; /* gxine exited */
+	  break;
+	case 1:
 	  write (STDOUT_FILENO, buf, 1);
+	  break;
+	}
       }
 
       if (FD_ISSET (STDIN_FILENO, &rset)) {
