@@ -13,10 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: desktop_integration.h,v 1.3 2002/11/25 12:19:27 guenter Exp $
+ * $Id: desktop_integration.h,v 1.5 2006-02-21 19:06:11 dsalt Exp $
  *
  * helper functions to register gxine with kde and gnome
  * (and possibly cde in the future)
@@ -25,11 +25,14 @@
 #ifndef HAVE_DESKTOP_INTEGRATION
 #define HAVE_DESKTOP_INTEGRATION
 
+#ifdef USE_INTEGRATION_WIZARD
+const char *di_registration_report (void);
+void di_registration_flush (void);
 void di_register_gnome (void);
-
 void di_register_kde (void);
-
 void di_register_mailcap (void);
+void di_register_mozilla (void);
+#endif
 
 #endif
 
