@@ -13,9 +13,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: drag_drop.c,v 1.8.2.2 2005/04/26 00:00:31 dsalt Exp $
+ * $Id: drag_drop.c,v 1.15 2006/04/08 00:44:46 dsalt Exp $
  *
  * drag and drop support for the main window
  */
@@ -106,18 +106,14 @@ void treeview_drag_drop_setup (GtkTreeView *widget,
 						gint, gint, GtkSelectionData *,
 						guint, guint))
 {
-  GObject *object = G_OBJECT(widget);
-
-  g_signal_connect (object, "drag-begin",
-		    G_CALLBACK (drag_start_cb), NULL);
-  g_signal_connect (object, "drag-data-get",
-		    G_CALLBACK (drag_data_get_cb), NULL);
-  g_signal_connect (object, "drag-data-received",
-		    G_CALLBACK (drop_cb), NULL);
-  g_signal_connect (object, "drag-end",
-		    G_CALLBACK (drag_end_cb), NULL);
-
-  gtk_tree_view_enable_model_drag_source (widget, 0, target_table + 1, 1,
+  g_object_connect (G_OBJECT (widget),
+	"signal::drag-begin", G_CALLBACK (drag_start_cb), NULL,
+	"signal::drag-data-get", G_CALLBACK (drag_data_get_cb), NULL,
+	"signal::drag-data-received", G_CALLBACK (drop_cb), NULL,
+	"signal::drag-end", G_CALLBACK (drag_end_cb), NULL,
+	NULL);
+  gtk_tree_view_enable_model_drag_source (widget, GDK_BUTTON1_MASK,
+					  target_table + 1, 1,
 					  GDK_ACTION_COPY | GDK_ACTION_MOVE);
   gtk_tree_view_enable_model_drag_dest (widget, target_table, 2,
 					GDK_ACTION_COPY | GDK_ACTION_MOVE);
@@ -158,7 +154,7 @@ int treeview_get_drop_index (GtkTreeView *widget, GdkDragContext *context,
 
 static void drag_data_received_cb (GtkWidget *widget, GdkDragContext *context,
 				   gint x, gint y, GtkSelectionData *data,
-				   guint info, guint time)
+				   guint info, guint time, gpointer autoplay)
 {
   logprintf ("drag_drop: drag callback, length=%d, format=%d\n",
 	     data->length, data->format);
@@ -166,7 +162,7 @@ static void drag_data_received_cb (GtkWidget *widget, GdkDragContext *context,
   if (data->format == 8)
   {
     int first = dnd_add_mrls (data, NULL, -1);
-    if (first >= 0)
+    if (first >= 0 && autoplay)
       playlist_play (first);
     gtk_drag_finish (context, TRUE, FALSE, time);
   }
@@ -174,10 +170,10 @@ static void drag_data_received_cb (GtkWidget *widget, GdkDragContext *context,
     gtk_drag_finish (context, FALSE, FALSE, time);
 }
 
-void drag_drop_setup (GtkWidget *widget)
+void drag_drop_setup (GtkWidget *widget, gboolean play)
 {
   gtk_drag_dest_set (widget, GTK_DEST_DEFAULT_ALL,
 		     target_table, 1, GDK_ACTION_COPY);
-  g_signal_connect (GTK_OBJECT (widget), "drag-data-received",
-		    G_CALLBACK (drag_data_received_cb), NULL);
+  g_signal_connect (G_OBJECT (widget), "drag-data-received",
+		    G_CALLBACK (drag_data_received_cb), play ? "" : NULL);
 }
