@@ -13,10 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: drag_drop.h,v 1.2 2005/01/31 19:04:45 dsalt Exp $
+ * $Id: drag_drop.h,v 1.4 2006-02-21 19:06:11 dsalt Exp $
  *
  * drag and drop support functions
  */
@@ -40,6 +40,6 @@ void treeview_drag_drop_setup (GtkTreeView *,
 						guint, guint));
 int treeview_get_drop_index (GtkTreeView *, GdkDragContext *, gint x, gint y);
 
-void drag_drop_setup (GtkWidget *);
+void drag_drop_setup (GtkWidget *, gboolean autoplay);
 
 #endif
