@@ -13,9 +13,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: gtkflipbutton.c,v 1.3 2005/01/09 20:56:43 dsalt Exp $
+ * $Id: gtkflipbutton.c,v 1.7 2006-02-21 19:06:11 dsalt Exp $
  *
  * GTK flip-button widget
  */
@@ -84,7 +84,7 @@ static gboolean gfb_toggled (GtkFlipButton *this)
 GtkWidget *
 gtk_flip_button_new (GtkWidget *inactive, GtkWidget *active)
 {
-  GtkWidget *this = GTK_WIDGET (gtk_type_new (gtk_flip_button_get_type ()));
+  GtkWidget *this = g_object_new (gtk_flip_button_get_type (), NULL);
   GtkWidget *table;
 
   ((GtkFlipButton *) this)->priv = malloc (sizeof (gtk_flip_button_private_t));
@@ -98,12 +98,20 @@ gtk_flip_button_new (GtkWidget *inactive, GtkWidget *active)
   gtk_widget_show_all (table);
   gtk_widget_unmap (active);
 
-  g_signal_connect_after ((GtkObject *)this, "toggled",
-			  G_CALLBACK(gfb_toggled), NULL);
-  g_signal_connect_after ((GtkObject *)this, "map-event",
-			  G_CALLBACK(gfb_toggled), NULL);
-  g_signal_connect_after ((GtkObject *)this, "show",
-			  G_CALLBACK(gfb_toggled), NULL);
+  g_object_connect ((GtkObject *)this,
+	"signal-after::toggled", G_CALLBACK(gfb_toggled), NULL,
+	"signal-after::map-event", G_CALLBACK(gfb_toggled), NULL,
+	"signal-after::show", G_CALLBACK(gfb_toggled), NULL,
+	NULL);
 
   return this;
 }
+
+GtkWidget *
+gtk_flip_button_new_from_stock (const char *inactive, const char *active,
+				GtkIconSize size)
+{
+  GtkWidget *wi = gtk_image_new_from_stock (inactive, size);
+  GtkWidget *wa = gtk_image_new_from_stock (active, size);
+  return gtk_flip_button_new (wi, wa);
+}
