@@ -15,17 +15,18 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
  *
- * $Id: http.h,v 1.3 2002/12/22 14:23:01 holstsn Exp $
+ * $Id: http.h,v 1.6 2006/04/04 22:08:52 dsalt Exp $
  */
 
 #ifndef HAVE_HTTP_H
 #define HAVE_HTTP_H
 
 
-char *http_download (const char *url, int *file_size);
+char *http_download (const char *url, ssize_t *file_size);
 
-int http_peek (const char *url, int size, char *contents, char *mime_type);
+ssize_t http_peek (const char *url, char *buffer, size_t buffer_size,
+	       char *mime_type, size_t mime_type_size);
 
 #endif
