@@ -13,10 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: key_events.h,v 1.6 2005/01/03 22:06:03 dsalt Exp $
+ * $Id: key_events.h,v 1.10 2006-03-10 19:24:51 dsalt Exp $
  *
  * key event handler, keymap editor
  */
@@ -39,8 +39,9 @@ struct kb_xine_event_map_s {
 };
 typedef struct kb_xine_event_map_s kb_xine_event_map_t;
 
-gint keypress_cb (GtkWidget *win, GdkEventKey *event);
-gint keyrelease_cb (GtkWidget *win, GdkEventKey *event);
+gboolean keypress_cb (GtkWidget *, GdkEventKey *, gpointer);
+gboolean buttonpress_cb (GtkWidget *, GdkEventButton *, gpointer);
+gboolean buttonrelease_cb (GtkWidget *, GdkEventButton *, gpointer);
 
 void kb_edit_show (void) ;
 
@@ -52,7 +53,8 @@ void save_key_bindings (void) ;
 int kb_xine_event_lookup (const kb_xine_event_map_t *, const char *);
 
 JSBool js_event_generic (JSContext *, JSObject *, uintN argc, jsval *argv,
-			 jsval *rval, const char *func, const char *mrlprefix,
-			 ...);
+			 jsval *rval, const char *func,
+			 const char *const *mrlprefix, ...)
+			 __attribute__ ((sentinel));
 
 #endif
