@@ -13,10 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: log_window.c,v 1.16 2005/01/03 22:06:03 dsalt Exp $
+ * $Id: log_window.c,v 1.20 2006/04/08 02:51:27 dsalt Exp $
  *
  * log window implementation
  */
@@ -37,16 +37,13 @@
 
 static GtkWidget *win;
 static GtkTextView *texts[MAX_TEXT];
-static gboolean is_visible;
-
-static void update_log_window () {
+static gboolean is_visible = FALSE;
 
+static void update_log_window (void)
+{
   int i;
-
   for (i = 0; i < xine_get_log_section_count (xine); ++i)
   {
-    int j;
-    char **log;
     GtkTextBuffer *buffer = gtk_text_view_get_buffer (texts[i]);
     GtkTextIter start, end;
 
@@ -54,11 +51,14 @@ static void update_log_window () {
     gtk_text_buffer_get_end_iter (buffer, &end);
     gtk_text_buffer_delete (buffer, &start, &end);
 
-    log = (char **) xine_get_log (xine, i);
+    const char *const *log = xine_get_log (xine, i);
 
     if (log)
+    {
+      int j;
       for (j = 0; log[j]; ++j)
 	gtk_text_buffer_insert (buffer, &end, log[j], -1);
+    }
   }
 }
 
@@ -76,57 +76,41 @@ static void response_cb (GtkDialog *dbox, int response, gpointer data)
 }
 
 static JSBool js_log_show (JSContext *cx, JSObject *obj, uintN argc, 
-			   jsval *argv, jsval *rval) {
-
-  /* se_t *se = (se_t *) JS_GetContextPrivate(cx); */
-
+			   jsval *argv, jsval *rval)
+{
   se_log_fncall ("log_show");
-
   log_window_show ();
-  
   return JS_TRUE;
 }
 
-void log_window_init () {
-
-  GtkWidget *tabs, *label;
-  int        i;
-  const char *const *names;
-
-  is_visible = FALSE;
-
-  /* 
-   * window 
-   */
+void log_window_init (void)
+{
+  /* window */
 
   win = gtk_dialog_new_with_buttons (_("xine engine log output"), NULL, 0,
 				GTK_STOCK_REFRESH, GTK_RESPONSE_YES,
 				GTK_STOCK_CLOSE, GTK_RESPONSE_DELETE_EVENT,
 				NULL);
-  g_signal_connect (GTK_OBJECT(win), "response",
-		    G_CALLBACK (response_cb), NULL);
+  g_signal_connect (G_OBJECT(win), "response", G_CALLBACK (response_cb), NULL);
   gtk_window_set_default_size (GTK_WINDOW (win), 640, 400);
   hide_on_delete (win, &is_visible);
 
-  /*
-   * notebook
-   */
+  /* notebook */
 
-  tabs = gtk_notebook_new();
+  GtkWidget *tabs = gtk_notebook_new();
 
-  names = xine_get_log_names (xine);
-  for (i=0; i<xine_get_log_section_count (xine); i++) {
-
-    GtkWidget *scroller;
-
-    label = gtk_label_new (names[i]);
+  const char *const *names = xine_get_log_names (xine);
+  int i;
+  for (i = 0; i < xine_get_log_section_count (xine); ++i)
+  {
+    GtkWidget *label = gtk_label_new (names[i]);
     texts[i] = GTK_TEXT_VIEW(gtk_text_view_new ());
     gtk_text_view_set_editable (texts[i], FALSE);
     gtk_text_view_set_cursor_visible (texts[i], FALSE);
     gtk_text_view_set_left_margin (texts[i], 2);
     gtk_text_view_set_right_margin (texts[i], 2);
 
-    scroller = gtk_scrolled_window_new (NULL, NULL);
+    GtkWidget *scroller = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroller),
 				    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scroller),
@@ -143,17 +127,17 @@ void log_window_init () {
 	    SE_GROUP_DIALOGUE, NULL, NULL);
 }
 
-void log_window_show (void) {
-
-  if (is_visible) {
+void log_window_show (void)
+{
+  if (is_visible)
+  {
     is_visible = FALSE;
     gtk_widget_hide (win);
-  } else {
+  }
+  else
+  {
     is_visible = TRUE;
-    gtk_widget_show_all (win);
+    window_show (win, NULL);
     update_log_window ();
   }
 }
-
-
-
