@@ -13,22 +13,25 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: mediamarks.h,v 1.6 2003/03/08 15:50:37 guenter Exp $
+ * $Id: mediamarks.h,v 1.9 2006-02-21 19:06:12 dsalt Exp $
  *
  */
 
 #ifndef HAVE_MEDIAMARKS_H
 #define HAVE_MEDIAMARKS_H
 
+#include "play_item.h"
+
 void mediamarks_init (void);
 void mm_save (void);
 
 /* dialogs : */
 
 void mm_manage_show (void);
-void mm_add_show (void);
+void mm_add_show (void *);
 void mm_import (void);
+void mm_add (play_item_t *);
 
 #endif
