@@ -13,67 +13,77 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: open_mrl.c,v 1.13 2004/12/02 19:43:11 dsalt Exp $
+ * $Id: open_mrl.c,v 1.32 2006/04/04 22:08:16 dsalt Exp $
  *
  * open mrl dialog (plus file browser)
  */
 
 #include "globals.h"
 
+#include <string.h>
+#include <stdlib.h>
+#include <ctype.h>
 #include <gtk/gtk.h>
 
 #include "open_mrl.h"
 #include "playlist.h"
+#include "ui.h"
 #include "utils.h"
 #include "script_engine.h"
+#include "history.h"
 
 static GtkWidget      *mrl_dialog;
 static gboolean        mrl_visible;
 static GtkWidget      *mrl_entry;
 
-void file_dialog_show(void) {
-
-  gchar **fnames;
-
-  fnames = modal_multi_file_dialog (_("Select file(s) to open"), NULL);
-  
-  if (fnames) {
-    int    pos, i;
-    gchar *mrl;
-
-    i = 0; pos = 0;
-    while ( (mrl = fnames[i]) ) {
-
-      if (i)
-	playlist_add_mrl (mrl, -1);
-      else
-	pos = playlist_add_mrl (mrl, -1);
-      
-      i++;
-    }
-
-    playlist_play (pos);
-  }
-
+void file_dialog_show(void)
+{
+  playlist_add_list
+    (modal_multi_file_dialog (_("Select files to add to playlist"),
+			      FALSE, NULL, app),
+     TRUE);
 }
 
-void file_dialog_init (void) {
+void file_dialog_init (void)
+{
+  /* nothing to do */
+}
 
-  /* nothing to be done natm */
+static gboolean responding = FALSE;
+
+static void
+open_mrl_activate_cb (GtkWidget *w, char *cmrl)
+{
+  while (isspace (*cmrl))
+    ++cmrl;
+  if (*cmrl)
+  {
+    int item = playlist_add_mrl (cmrl, -1);
+    playlist_play (item);
+  }
+  if (!responding)
+  {
+    mrl_visible = FALSE;
+    gtk_widget_hide (mrl_dialog);
+  }
 }
 
 static void open_mrl_response_cb (GtkDialog *dbox, int response, gpointer data)
 {
-  const gchar  *mrl;
-  int           item;
   switch (response)
   {
+  case 1:
+    get_mrl_from_filesystem ((GtkWindow *)mrl_dialog,
+			     (GtkEntry *)history_combo_box_get_entry (mrl_entry));
+    break;
+
   case GTK_RESPONSE_OK:
-    mrl = gtk_entry_get_text (GTK_ENTRY (mrl_entry));
-    item = playlist_add_mrl (mrl, -1);
-    playlist_play (item); /* then hide */
+    responding = TRUE;
+    history_combo_box_activate (mrl_entry);
+    responding = FALSE;
+
   default:
     mrl_visible = FALSE;
     gtk_widget_hide (mrl_dialog);
@@ -81,55 +91,54 @@ static void open_mrl_response_cb (GtkDialog *dbox, int response, gpointer data)
 }
 
 static JSBool js_open_show (JSContext *cx, JSObject *obj, uintN argc, 
-			    jsval *argv, jsval *rval) {
-
+			    jsval *argv, jsval *rval)
+{
   /* se_t *se = (se_t *) JS_GetContextPrivate(cx); */
-
-  se_log_fncall ("open_show");
-
+  se_log_fncall_checkinit ("open_show");
   file_dialog_show ();
-  
   return JS_TRUE;
 }
 
 static JSBool js_open_mrl_show (JSContext *cx, JSObject *obj, uintN argc, 
-				jsval *argv, jsval *rval) {
-
+				jsval *argv, jsval *rval)
+{
   /* se_t *se = (se_t *) JS_GetContextPrivate(cx); */
-
-  se_log_fncall ("open_mrl_show");
-
+  se_log_fncall_checkinit ("open_mrl_show");
   open_mrl_show ();
-  
   return JS_TRUE;
 }
 
-void open_mrl_init (void) {
+void open_mrl_init (void)
+{
+  GtkWidget *hbox;
 
-  GtkWidget *label, *hbox;
+  mrl_dialog = gtk_dialog_new_with_buttons (_("Open MRL..."), NULL, 0, NULL);
+  gtk_dialog_add_action_widget (GTK_DIALOG(mrl_dialog),
+				ui_button_new_stock_mnemonic
+				  (GTK_STOCK_OPEN, _("_File...")),
+				1);
+  gtk_dialog_add_buttons (GTK_DIALOG(mrl_dialog),
+			  GTK_STOCK_CANCEL, GTK_RESPONSE_DELETE_EVENT,
+			  GTK_STOCK_OK, GTK_RESPONSE_OK,
+			  NULL);
 
-  mrl_dialog = gtk_dialog_new_with_buttons (_("Open MRL..."), NULL, 0,
-				GTK_STOCK_CANCEL, GTK_RESPONSE_DELETE_EVENT,
-				GTK_STOCK_OK, GTK_RESPONSE_OK,
-				NULL);
-
-  gtk_window_set_default_size (GTK_WINDOW (mrl_dialog), 400, 150);
+  gtk_window_set_default_size (GTK_WINDOW (mrl_dialog), 400, -1);
   gtk_window_set_position (GTK_WINDOW (mrl_dialog), GTK_WIN_POS_CENTER);
   hide_on_delete (mrl_dialog, &mrl_visible);
-  g_signal_connect (GTK_OBJECT (mrl_dialog), "response",
+  g_signal_connect (G_OBJECT (mrl_dialog), "response",
 		    G_CALLBACK (open_mrl_response_cb), NULL);
   gtk_dialog_set_default_response (GTK_DIALOG(mrl_dialog), GTK_RESPONSE_OK);
 
   hbox = gtk_hbox_new (0, 2);
+  gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (mrl_dialog)->vbox), hbox);
 
-  label = gtk_label_new ("mrl:");
-
-  gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
-
-  mrl_entry = gtk_entry_new ();
+  mrl_entry = history_combo_box_new (open_mrl_activate_cb);
   gtk_box_pack_start (GTK_BOX(hbox), mrl_entry, TRUE, TRUE, 2);
 
-  gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (mrl_dialog)->vbox), hbox);
+  GtkWidget *b = ui_button_new_stock_mnemonic (GTK_STOCK_CLEAR, _("_Flush"));
+  gtk_box_pack_start (GTK_BOX (hbox), b, FALSE, FALSE, 0);
+  g_signal_connect_swapped (b, "clicked",
+			    G_CALLBACK (history_combo_box_clear), mrl_entry);
 
   mrl_visible = 0;
 
@@ -149,7 +158,7 @@ void open_mrl_show (void) {
     gtk_widget_hide (mrl_dialog);
   } else {
     mrl_visible = TRUE;
-    gtk_widget_show_all (mrl_dialog);
+    window_show (mrl_dialog, NULL);
     gtk_widget_grab_focus (mrl_entry);
   }
 }
