@@ -13,10 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: playlist.h,v 1.12 2005/01/28 02:16:27 dsalt Exp $
+ * $Id: playlist.h,v 1.17 2006-02-21 19:06:11 dsalt Exp $
  *
  * playlist for gxine
  */
@@ -30,9 +30,11 @@ void playlist_init (void);
 void playlist_show (void);
 
 void playlist_clear (void);
+int playlist_flush (play_item_type);
 
 int  playlist_add     (play_item_t *play_item, gint ins_pos /* -1 => append */);
 int  playlist_add_mrl (const char *mrl, gint ins_pos /* -1 => append */) ;
+void playlist_add_list (GSList *, gboolean play); /* also frees the list */
 
 void playlist_check_set_title (void);
 
@@ -43,8 +45,9 @@ void playlist_logo (void);
 
 int playlist_showing_logo (void);
 
-play_item_t *playlist_get_item     (int list_pos);
+play_item_t *playlist_get_item     (int list_pos); /* pointer; NOT a copy! */
 int          playlist_get_list_pos (void); /*of currently played entry*/
+play_item_t *playlist_get_current_item (void); /* copy of current; unedited */
 
 int playlist_size (void);
 
