@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2005 the xine-project
+ * Copyright (C) 2004-2006 the xine-project
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,14 +13,19 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: post.c,v 1.20.2.3 2005/08/01 22:47:17 dsalt Exp $
+ * $Id: post.c,v 1.45 2006/04/09 14:27:29 dsalt Exp $
  *
  * post-plugin handling
  */
 
+#ifdef GTK_DISABLE_DEPRECATED
+/* Use GtkOptionMenu because tooltips can be added to its items */
+# undef GTK_DISABLE_DEPRECATED
+#endif
+
 #include "globals.h"
 
 #include <xine.h>
@@ -32,9 +37,12 @@
 
 #include "post.h"
 #include "gtkvideo.h"
+#include "preferences.h"
+#include "ui.h"
 #include "utils.h"
 
 typedef enum {
+  POST_CHAIN_DEINTERLACE,
   POST_CHAIN_VIDEO,
   POST_CHAIN_AUDIO,
   POST_CHAIN_LAST,
@@ -59,9 +67,12 @@ struct gxine_post_s {
 };
 typedef struct gxine_post_s gxine_post_t;
 
-static gxine_chain_t chains[] = { { POST_CHAIN_VIDEO }, { POST_CHAIN_AUDIO } };
+static gxine_chain_t chains[] = {
+  { POST_CHAIN_DEINTERLACE }, { POST_CHAIN_VIDEO }, { POST_CHAIN_AUDIO }
+};
 
-static const char *cfgname[] = {
+static const char *const cfgname[] = {
+  "gui.post_plugins.deinterlace",
   "gui.post_plugins.video",
   "gui.post_plugins.audio"
 };
@@ -69,12 +80,18 @@ static const char *cfgname[] = {
 static const void *const empty[] = { NULL };
 
 static const char *const chain_title[] = {
+  N_("Configure deinterlace post-plugins"),
   N_("Configure video post-plugins"),
   N_("Configure audio post-plugins")
 };
 
 static GtkTooltips *tips = NULL;
 
+static xine_video_port_t *vo_none = NULL;
+static xine_audio_port_t *ao_none = NULL;
+
+extern const char *xine_get_post_plugin_description () __attribute__((weak));
+
 static char *
 post_parse_parameters (xine_post_t *plugin, const char *paramstr)
 {
@@ -153,14 +170,12 @@ post_parse_parameters (xine_post_t *plugin, const char *paramstr)
 	  goto next_param;
 
 	case POST_PARAM_TYPE_STRING:
-	  fprintf (stderr,
-		   "gxine: post-parameter type %s not yet supported\n",
+	  g_printerr (_("gxine: post-parameter type %s not yet supported\n"),
 		   "STRING");
 	  goto next_param;
 
 	case POST_PARAM_TYPE_STRINGLIST:
-	  fprintf (stderr,
-		   "gxine: post-parameter type %s not yet supported\n",
+	  g_printerr (_("gxine: post-parameter type %s not yet supported\n"),
 		   "STRINGLIST");
 	  goto next_param;
 
@@ -171,8 +186,7 @@ post_parse_parameters (xine_post_t *plugin, const char *paramstr)
 	  goto next_param;
 
 	default:
-	  fprintf (stderr,
-		   "gxine: post-parameter type %s not yet supported\n",
+	  g_printerr (_("gxine: post-parameter type %s not yet supported\n"),
 		   "???");
 	  goto next_param;
 	}
@@ -317,8 +331,8 @@ post_config_post_revert (gxine_post_t *info)
     {
     case POST_PARAM_TYPE_INT:
       if (param[i].enum_values)
-	gtk_option_menu_set_history (GTK_OPTION_MENU(info->conf_w[i]),
-				     *(int *)param_p);
+	gtk_combo_box_set_active (GTK_COMBO_BOX(info->conf_w[i]),
+				  *(int *)param_p);
       else
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON(info->conf_w[i]),
 				   *(int *)param_p);
@@ -330,8 +344,8 @@ post_config_post_revert (gxine_post_t *info)
 
     case POST_PARAM_TYPE_CHAR:
       {
-	char *contents = alloca (param->size + 1);
-	sprintf (contents, "%.*s", param->size, (char *)param_p);
+	char *contents = alloca (param[i].size + 1);
+	sprintf (contents, "%.*s", param[i].size, (char *)param_p);
 	gtk_entry_set_text (GTK_ENTRY(info->conf_w[i]), contents);
       }
       break;
@@ -381,9 +395,9 @@ post_config_post_response (GtkDialog *dbox, gint response, gxine_post_t *info)
 }
 
 static void
-enum_cb (GtkOptionMenu *widget, int *param)
+enum_cb (GtkComboBox *widget, int *param)
 {
-  *param = gtk_option_menu_get_history (widget);
+  *param = gtk_combo_box_get_active (widget);
 }
 
 static void
@@ -415,13 +429,13 @@ text_insert_cb (GtkEditable *widget, const gchar *text, gint length,
 {
   int i, j;
   gchar *newtext = malloc (length);
-  /* we can't allow ';' as it has a special meaning */
+  /* we can't allow ';' or ',' as they have special meanings */
   for (i = j = 0; i < length; ++i)
-    if (text[i] >= ' ' && text[i] != ';')
+    if (text[i] >= ' ' && text[i] != ';' && text[i] != ',')
       newtext[j++] = text[i];
-  g_signal_handlers_block_by_func (widget, (gpointer)text_insert_cb, data);
+  g_signal_handlers_block_by_func (widget, text_insert_cb, data);
   gtk_editable_insert_text (widget, newtext, j, position);
-  g_signal_handlers_unblock_by_func (widget, (gpointer)text_insert_cb, data);
+  g_signal_handlers_unblock_by_func (widget, text_insert_cb, data);
   g_signal_stop_emission_by_name (widget, "insert-text");
   free (newtext);
 }
@@ -483,6 +497,8 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
 				 NULL);
   g_signal_connect (G_OBJECT(info->dbox), "response",
 		    G_CALLBACK(post_config_post_response), info);
+  gtk_dialog_set_default_response (GTK_DIALOG (info->dbox), GTK_RESPONSE_OK);
+  ui_add_undo_response (info->dbox, NULL);
   free (title);
   table = gtk_table_new (1, 2, FALSE);
   gtk_box_pack_start (GTK_BOX(GTK_DIALOG(info->dbox)->vbox), table,
@@ -502,16 +518,13 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
     case POST_PARAM_TYPE_INT:
       if (param->enum_values)
       {
-	GtkWidget *items = gtk_menu_new ();
-	char *v;
-	int i = -1;
-	while ((v = param->enum_values[++i]))
-	  gtk_menu_shell_append (GTK_MENU_SHELL(items),
-				 gtk_menu_item_new_with_label (v));
-	widget = gtk_option_menu_new ();
-	gtk_option_menu_set_menu (GTK_OPTION_MENU(widget), items);
-	gtk_option_menu_set_history (GTK_OPTION_MENU(widget), *(int *)param_p);
-	g_signal_connect (GTK_OBJECT(widget), "changed",
+	int i;
+	widget = gtk_combo_box_new_text ();
+	for (i = 0; param->enum_values[i]; ++i)
+	  gtk_combo_box_append_text (GTK_COMBO_BOX(widget),
+				     param->enum_values[i]);
+	gtk_combo_box_set_active (GTK_COMBO_BOX(widget), *(int *)param_p);
+	g_signal_connect (G_OBJECT(widget), "changed",
 			  G_CALLBACK(enum_cb), param_p);
       }
       else
@@ -522,7 +535,7 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
 	gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON(widget),
 					   GTK_UPDATE_ALWAYS);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON(widget), TRUE);
-	g_signal_connect (GTK_OBJECT(widget), "value-changed",
+	g_signal_connect (G_OBJECT(widget), "value-changed",
 			  G_CALLBACK(spin_cb), param_p);
       }
       break;
@@ -544,7 +557,7 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
 	gtk_scale_set_draw_value (GTK_SCALE(widget), TRUE);
 	gtk_scale_set_value_pos (GTK_SCALE(widget), GTK_POS_TOP);
 	gtk_scale_set_digits (GTK_SCALE(widget), floating ? 2 : 0); /* hmm... */
-	g_signal_connect (GTK_OBJECT (adj), "value-changed",
+	g_signal_connect (G_OBJECT (adj), "value-changed",
 			  G_CALLBACK (range_cb), param_p);
       }
       break;
@@ -556,10 +569,10 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
 	sprintf (contents, "%.*s", param->size, (char *)param_p);
 	gtk_entry_set_text (GTK_ENTRY(widget), contents);
 	g_object_set_data (G_OBJECT(widget), "post", info);
-	g_signal_connect (GTK_OBJECT(widget), "insert-text",
-			  G_CALLBACK(text_insert_cb), NULL);
-	g_signal_connect (GTK_OBJECT(widget), "focus-out-event",
-			  G_CALLBACK(char_entry_cb), (gpointer)param);
+	g_object_connect (G_OBJECT(widget),
+		"signal::insert-text", G_CALLBACK(text_insert_cb), NULL,
+		"signal::focus-out-event", G_CALLBACK(char_entry_cb), (gpointer)param,
+		NULL);
       }
       break;
 
@@ -567,7 +580,7 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
       widget = gtk_check_button_new();
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(widget),
 				    *(char *)param_p);
-      g_signal_connect (GTK_OBJECT(widget), "toggled",
+      g_signal_connect (G_OBJECT(widget), "toggled",
 			G_CALLBACK(check_box_cb), param_p);
       break;
 
@@ -595,7 +608,7 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
     size_t p = strlen (helptext);
 
     /* lose trailing whitespace (and control codes) */
-    while (p >= 0 && helptext[p] < 33)
+    while (helptext[p] < 33)
       --p;
     helptext[p + 1] = 0;
 
@@ -642,7 +655,7 @@ post_config_post_window (GtkButton *widget, gxine_post_t *info)
   }
 
   hide_on_delete (info->dbox, NULL);
-  gtk_widget_show_all (info->dbox);
+  window_show (info->dbox, info->parent->dbox);
 
   {
     GdkGeometry geom;
@@ -663,13 +676,11 @@ post_config_post_init_plugin (post_chain_t chain_type, const char *name)
   logprintf ("post_config: creating plugin '%s'\n", name);
   switch (chain_type)
   {
+  case POST_CHAIN_DEINTERLACE:
   case POST_CHAIN_VIDEO:
-    {
-      xine_video_port_t *port = gtk_video_get_port ((GtkVideo *)gtv);
-      return xine_post_init (xine, name, 0, NULL, &port);
-    }
+    return xine_post_init (xine, name, 0, NULL, &vo_none);
   case POST_CHAIN_AUDIO:
-    return xine_post_init (xine, name, 0, &audio_port, NULL);
+    return xine_post_init (xine, name, 0, &ao_none, NULL);
   default:
     return NULL; /* shouldn't happen */
   }
@@ -681,7 +692,7 @@ static void
 reconfigure_plugins (gxine_chain_t *chain)
 {
   char *params = NULL;
-  GSList *info = chain->plugins;
+  GSList *info;
   xine_cfg_entry_t entry;
 
   logprintf ("post_config: configuring plugins\n");
@@ -689,7 +700,7 @@ reconfigure_plugins (gxine_chain_t *chain)
   if (!xine_config_lookup_entry (xine, cfgname[chain->type], &entry))
     return;
 
-  for (; info; info = info->next)
+  foreach_glist (info, chain->plugins)
   {
     const gxine_post_t *post = info->data;
     gboolean enabled =
@@ -699,15 +710,16 @@ reconfigure_plugins (gxine_chain_t *chain)
   }
 
   entry.str_value = params ? : "";
-  xine_config_update_entry (xine, &entry);
+  preferences_update_entry (&entry);
 
   free (params);
 }
 
 typedef struct { GtkOptionMenu *menu; int index; } reset_pp_t;
 
-static gboolean reset_pp (reset_pp_t *info)
+static gboolean reset_pp (gpointer data)
 {
+  reset_pp_t *info = data;
   gtk_option_menu_set_history (info->menu, info->index);
   free (info);
   return FALSE;
@@ -733,9 +745,10 @@ post_config_post_chain_set_plugin (GtkOptionMenu *menu, gxine_post_t *info)
   newplugin = post_config_post_init_plugin (chain->type, name);
   if (!newplugin)
   {
-    display_error (gettext (chain_title[chain->type]), NULL,
-		   _("Couldn't initialise plugin '%s' for configuration"),
-		   name);
+    display_error_modal (FROM_XINE, _("Plugin error"),
+	/* problem - we can't instantiate the plugin so we can't configure it */
+			 _("Couldn't initialise plugin ‘%s’ for configuration"),
+			 name);
     if (info->name && strcmp (name, info->name))
     {
       int i;
@@ -761,6 +774,12 @@ post_config_post_chain_set_plugin (GtkOptionMenu *menu, gxine_post_t *info)
   info->plugin = newplugin;
   gtk_widget_set_sensitive
     (info->pref, xine_post_input (info->plugin, "parameters") != NULL);
+
+  gtk_tooltips_set_tip (tips, (GtkWidget *)menu,
+			xine_get_post_plugin_description
+			  ? xine_get_post_plugin_description (xine, name)
+			  : NULL,
+			NULL);
 }
 
 static void
@@ -786,7 +805,8 @@ post_config_post_chain_move_plugin (GtkButton *widget, gxine_post_t *info)
   if (--pos < 0)
     return;
   logprintf ("post_config: moving plugin '%s' up\n", info->name);
-  g_slist_remove (info->parent->plugins, info); /* this is not the first item */
+  /* we're not removing the first item, but keep the compiler happy :-) */
+  info->parent->plugins = g_slist_remove (info->parent->plugins, info);
   info->parent->plugins = g_slist_insert (info->parent->plugins, info, pos);
   gtk_box_reorder_child (GTK_BOX(info->box->parent), info->box, pos);
   gtk_widget_set_sensitive (info->up, pos);
@@ -795,8 +815,6 @@ post_config_post_chain_move_plugin (GtkButton *widget, gxine_post_t *info)
      TRUE);
 }
 
-extern const char *xine_get_post_plugin_description () __attribute__((weak));
-
 static void
 post_config_post_add_plugin (gxine_chain_t *chain, xine_post_t *post,
 			     gboolean enabled, char *name, char *params)
@@ -804,6 +822,7 @@ post_config_post_add_plugin (gxine_chain_t *chain, xine_post_t *post,
   gxine_post_t *info = malloc (sizeof (gxine_post_t));
   GtkWidget *w, *m;
   int i, history = 0;
+  const char *hist_desc = NULL;
 
   logprintf ("post_config: adding plugin '%s'\n", name);
   info->parent = chain;
@@ -825,7 +844,10 @@ post_config_post_add_plugin (gxine_chain_t *chain, xine_post_t *post,
 		     : NULL;
     GtkWidget *item;
     if (!strcmp (chain->names[i], name))
+    {
       history = i;
+      hist_desc = desc;
+    }
     gtk_menu_shell_append (GTK_MENU_SHELL(m),
 			item =   gtk_menu_item_new_with_label (chain->names[i]));
     if (desc)
@@ -836,17 +858,17 @@ post_config_post_add_plugin (gxine_chain_t *chain, xine_post_t *post,
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), enabled);
   gtk_box_pack_start (GTK_BOX(info->box), w, FALSE, TRUE, 0);
 
+  /* FIXME but not until combo box menu items can have tooltips */
   w = gtk_option_menu_new ();
   gtk_option_menu_set_menu (GTK_OPTION_MENU(w), m);
   gtk_option_menu_set_history (GTK_OPTION_MENU(w), history);
   gtk_box_pack_start_defaults (GTK_BOX(info->box), w);
   g_signal_connect (G_OBJECT(w), "changed",
 		    G_CALLBACK(post_config_post_chain_set_plugin), info);
+  if (hist_desc)
+    gtk_tooltips_set_tip (tips, w, hist_desc, NULL);
 
-  info->up = w = gtk_button_new ();
-  gtk_container_add (GTK_CONTAINER(w),
-		     gtk_image_new_from_stock (GTK_STOCK_GO_UP,
-					       GTK_ICON_SIZE_BUTTON));
+  info->up = w = ui_button_new_stock (GTK_STOCK_GO_UP);
   gtk_widget_set_sensitive (w, !!chain->plugins); /* disable for first plugin */
   gtk_box_pack_end (GTK_BOX(info->box), w, FALSE, TRUE, 0);
   g_signal_connect (G_OBJECT(w), "clicked",
@@ -880,9 +902,9 @@ post_config_post_chain_add (GtkButton *button, gxine_chain_t *chain)
     post_config_post_add_plugin (chain, plugin, TRUE, strdup (chain->names[0]),
 				 strdup (""));
   else
-    display_error (gettext (chain_title[chain->type]), NULL,
-		   _("Couldn't initialise plugin '%s' for configuration"),
-		   chain->names[0]);
+    display_error_modal (FROM_XINE, _("Plugin error"),
+			 _("Couldn't initialise plugin ‘%s’ for configuration"),
+			 chain->names[0]);
 }
 
 static void
@@ -965,11 +987,13 @@ static JSBool
 post_config_post_chain_window (gxine_chain_t *chain)
 {
   static const int post_type[] = {
+    XINE_POST_TYPE_VIDEO_FILTER,
     XINE_POST_TYPE_VIDEO_FILTER,
     XINE_POST_TYPE_AUDIO_FILTER
   };
   GtkWidget *hbox, *w;
   const char *const *plugin_list;
+  char *title;
   int i;
 
   if (chain->dbox)
@@ -981,8 +1005,11 @@ post_config_post_chain_window (gxine_chain_t *chain)
   plugin_list = xine_list_post_plugins_typed (xine, post_type[chain->type]);
   if (!plugin_list || !plugin_list[0])
   {
-    display_error (gettext (chain_title[chain->type]), NULL,
-		   _("No available plugins - nothing to configure"));
+    title = g_markup_printf_escaped (_("Plugin chain %s"),
+				     gettext (chain_title[chain->type]));
+    display_info (FROM_XINE, title,
+		  _("No available plugins - nothing to configure"));
+    free (title);
     return JS_FALSE;
   }
 
@@ -993,16 +1020,20 @@ post_config_post_chain_window (gxine_chain_t *chain)
 
   logprintf ("post_config: start\n");
 
+  title = g_strdup_printf (_("Plugin chain %s"),
+			   gettext (chain_title[chain->type]));
   chain->dbox = gtk_dialog_new_with_buttons
-		  (gettext (chain_title[chain->type]), NULL, 0,
+		  (title, NULL, 0,
 		   GTK_STOCK_UNDO, GTK_RESPONSE_REJECT,
 		   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		   GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
 		   GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 		   NULL);
+  free (title);
   hide_on_delete (chain->dbox, NULL);
   g_signal_connect (G_OBJECT(chain->dbox), "response",
 		    G_CALLBACK(post_config_post_chain_response), chain);
+  ui_add_undo_response (chain->dbox, NULL);
   if (!tips)
     tips = gtk_tooltips_new ();
 
@@ -1017,58 +1048,23 @@ post_config_post_chain_window (gxine_chain_t *chain)
 
   post_config_post_chain_build (chain);
 
-  gtk_widget_show_all (chain->dbox);
+  window_show (chain->dbox, NULL);
   return JS_TRUE;
 }
 
-static void
-deinterlace_reconfigure (gxine_post_t *info)
-{
-  xine_cfg_entry_t entry;
-  char *cfg, *params = post_make_parameter_string (info);
-  logprintf ("post_config: deinterlace configuration\n  was: %s\n  now: %s\n",
-	     info->parameters, params);
-  free (info->parameters);
-  cfg = g_strdup_printf ("tvtime:%s", info->parameters = params);
-  gtk_video_set_tvtime (GTK_VIDEO(gtv), cfg);
-  if (xine_config_lookup_entry (xine, "gui.post_plugins.deinterlace", &entry))
-  {
-    entry.str_value = cfg;
-    xine_config_update_entry (xine, &entry);
-  }
-  free (cfg);
-}
-
 static JSBool
 js_deinterlace_show (JSContext *cx, JSObject *obj, uintN argc,
 		     jsval *argv, jsval *rval)
 {
-  xine_cfg_entry_t entry;
-  static gxine_post_t info = {
-    NULL, "tvtime", .reconfigure = deinterlace_reconfigure
-  };
-
-  se_log_fncall ("deinterlace_show");
-  if (info.dbox)
-    return JS_FALSE;
-
-  if (!xine_config_lookup_entry (xine, "gui.post_plugins.deinterlace", &entry))
-    return JS_FALSE;
-
-  info.name = _("deinterlace (tvtime)");
-  info.plugin = gtk_video_get_deinterlacer (GTK_VIDEO(gtv));
-  free (info.parameters);
-  info.parameters = strdup (entry.str_value +
-			    (strncmp (entry.str_value, "tvtime:", 7) ? 0 : 7));
-
-  return post_config_post_window (NULL, &info);
+  se_log_fncall_checkinit ("deinterlace_show");
+  return post_config_post_chain_window (&chains[POST_CHAIN_DEINTERLACE]);
 }
 
 static JSBool
 js_pp_video_show (JSContext *cx, JSObject *obj, uintN argc,
 		  jsval *argv, jsval *rval)
 {
-  se_log_fncall ("postproc_video_show");
+  se_log_fncall_checkinit ("postproc_video_show");
   return post_config_post_chain_window (&chains[POST_CHAIN_VIDEO]);
 }
 
@@ -1076,7 +1072,7 @@ static JSBool
 js_pp_audio_show (JSContext *cx, JSObject *obj, uintN argc,
 		  jsval *argv, jsval *rval)
 {
-  se_log_fncall ("postproc_audio_show");
+  se_log_fncall_checkinit ("postproc_audio_show");
   return post_config_post_chain_window (&chains[POST_CHAIN_AUDIO]);
 }
 
@@ -1093,4 +1089,7 @@ post_init (void)
     { NULL }
   };
   se_defuns (gse, NULL, defs);
+
+  vo_none = xine_open_video_driver (xine, "none", 0, NULL);
+  ao_none = xine_open_audio_driver (xine, "none", NULL);
 }
