@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2005 the xine project
+ * Copyright (C) 2001-2006 the xine project
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: preferences.c,v 1.44 2005/01/09 20:56:44 dsalt Exp $
+ * $Id: preferences.c,v 1.61 2006/04/05 19:08:33 dsalt Exp $
  *
  * Functions to stup and deal with a preferences dialog interfacing with
  * the xine config system.
@@ -40,16 +40,7 @@
 #include "preferences.h"
 #include "utils.h"
 
-#define XP_UNIX
-#ifdef HAVE_LIBSMJS
-# ifdef LIBJS_IS_SMJS
-#  include <js/jsapi.h>
-# else
-#  include <smjs/jsapi.h>
-# endif
-#else
-# include "spidermonkey/jsapi.h"
-#endif
+#include <jsapi.h>
 
 
 typedef struct {
@@ -75,6 +66,7 @@ typedef union {
 
 static GtkWidget  *prefs_dialog;
 static GNode	  *prefs = NULL;
+static GData	  *prefs_map = NULL;
 static int         is_visible;
 static GtkTooltips *tooltips = NULL;
 static int         update_lock = 0;
@@ -87,7 +79,7 @@ static int select_show_prefs_internal (GNode *page, int exp)
   pref_t *parent = page->parent ? page->parent->data : NULL;
   GNode *child;
 
-  if (parent && parent->notebook == (void *) 1)
+  if (parent && parent->notebook == GINT_TO_POINTER (1))
     return 0; /* called too early */
 
   child = g_node_first_child (page);
@@ -135,14 +127,6 @@ static int select_show_prefs_internal (GNode *page, int exp)
     gtk_notebook_append_page (GTK_NOTEBOOK(parent->notebook), item->page.page,
 			      gtk_label_new (item->page.label));
 
-  if (parent)
-  {
-    gboolean multi =
-      gtk_notebook_get_n_pages (GTK_NOTEBOOK(parent->notebook)) > 1;
-    gtk_notebook_set_show_tabs (GTK_NOTEBOOK(parent->notebook), multi);
-    gtk_notebook_set_show_border (GTK_NOTEBOOK(parent->notebook), multi);
-  }
-
   return state;
 }
 
@@ -151,8 +135,7 @@ static gboolean select_show_pref_widgets (void *data)
   static const int experience_values[] = { 0, 10, 20, 30 };
   int exp = *(int *)data;
 
-  if (exp >= 0 && exp < sizeof (experience_values) /
-			sizeof (experience_values[0]))
+  if (exp >= 0 && exp < (int) G_N_ELEMENTS (experience_values))
     exp = experience_values[exp];
   else
     exp = 0;
@@ -291,7 +274,7 @@ static void enum_cb (GtkWidget* widget, gpointer data)
   if (!xine_config_lookup_entry (xine, key, &entry))
     return;
 
-  pos = gtk_option_menu_get_history (GTK_OPTION_MENU(widget));
+  pos = gtk_combo_box_get_active (GTK_COMBO_BOX(widget));
 
   if (entry.num_value != pos)
   {
@@ -311,16 +294,17 @@ static GtkWidget *create_item_editable (const xine_cfg_entry_t *entry)
   switch (entry->type) {
   case XINE_CONFIG_TYPE_ENUM:
     {
-      GtkWidget *items = gtk_menu_new ();
-      char *v;
-      int i = -1;
-      while ((v = entry->enum_values[++i]))
-        gtk_menu_shell_append (GTK_MENU_SHELL(items),
-			       gtk_menu_item_new_with_label (gettext (v)));
-      widget = gtk_option_menu_new ();
-      gtk_option_menu_set_menu (GTK_OPTION_MENU(widget), items);
-      gtk_option_menu_set_history (GTK_OPTION_MENU(widget), entry->num_value);
-      g_signal_connect (GTK_OBJECT(widget), "changed",
+      int i;
+      widget = gtk_combo_box_new_text ();
+      for (i = 0; entry->enum_values[i]; ++i)
+      {
+	const char *label = gettext (entry->enum_values[i]);
+	if (label == entry->enum_values[i])
+	  label = dgettext (LIB_PACKAGE, label);
+	gtk_combo_box_append_text (GTK_COMBO_BOX(widget), label);
+      }
+      gtk_combo_box_set_active (GTK_COMBO_BOX(widget), entry->num_value);
+      g_signal_connect (G_OBJECT(widget), "changed",
 			G_CALLBACK(enum_cb), strdup(entry->key));
     }
     break;
@@ -328,10 +312,10 @@ static GtkWidget *create_item_editable (const xine_cfg_entry_t *entry)
   case XINE_CONFIG_TYPE_STRING:
     widget = gtk_entry_new();
     g_object_set_data (G_OBJECT(widget), "cfg", (gpointer)entry->key);
-    g_signal_connect (GTK_OBJECT(widget), "key-press-event",
-		      G_CALLBACK(entry_keypress_cb), (gchar *)entry->key);
-    g_signal_connect (GTK_OBJECT(widget), "focus-out-event",
-		      G_CALLBACK(entry_cb), (gchar *)entry->key);
+    g_object_connect (G_OBJECT(widget),
+	"signal::key-press-event", G_CALLBACK(entry_keypress_cb), (gchar *)entry->key,
+	"signal::focus-out-event", G_CALLBACK(entry_cb), (gchar *)entry->key,
+	NULL);
     gtk_entry_set_text (GTK_ENTRY(widget), entry->str_value);
     break;
 
@@ -356,7 +340,7 @@ static GtkWidget *create_item_editable (const xine_cfg_entry_t *entry)
       gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON(widget),
 					 GTK_UPDATE_ALWAYS);
       gtk_spin_button_set_numeric (GTK_SPIN_BUTTON(widget), TRUE);
-      g_signal_connect (GTK_OBJECT(widget), "value-changed",
+      g_signal_connect (G_OBJECT(widget), "value-changed",
 			G_CALLBACK(spin_cb), (gchar *)entry->key);
     }
     break;
@@ -365,37 +349,36 @@ static GtkWidget *create_item_editable (const xine_cfg_entry_t *entry)
     widget = gtk_check_button_new();
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(widget),
 				  entry->num_value == 1);
-    g_signal_connect (GTK_OBJECT(widget), "toggled",
+    g_signal_connect (G_OBJECT(widget), "toggled",
 		      G_CALLBACK(check_box_cb), (gchar *)entry->key);
     /* gtk_misc_set_alignment (GTK_MISC(widget), 1.0, 1.0); */
     break;
 
   default:
     widget = gtk_label_new ("?");
-    printf ("preferences: unknown type for entry '%s'\n", entry->key);
+    g_print (_("preferences: unknown type for entry ‘%s’\n"), entry->key);
   }
 
+  g_datalist_set_data (&prefs_map, entry->key, widget);
   gtk_tooltips_set_tip (tooltips, widget, entry->help, NULL);
   return widget;
 }
 
 static GtkWidget *create_item_label (const xine_cfg_entry_t *entry)
 {
-  char *desc, *labelkey, *labeltext;
   GtkWidget *label;
+  char *labeltext;
+  const char *labelkey = strrchr (entry->key, '.') + 1;
 
-  desc = g_markup_escape_text (entry->description, strlen (entry->description));
-  labelkey = strrchr (entry->key, '.') + 1;
-  labelkey = g_markup_escape_text (labelkey, strlen (labelkey));
   if (entry->callback_data)
-    labeltext = g_strdup_printf ("<b>%s</b>\n%s", labelkey, desc);
+    labeltext = g_markup_printf_escaped ("<b>%s</b>\n%s",
+					 labelkey, entry->description);
   else
-    labeltext = g_strdup_printf ("<b>• <i>%s</i></b>\n%s", labelkey, desc);
+    labeltext = g_markup_printf_escaped ("<b>• <i>%s</i></b>\n%s",
+					 labelkey, entry->description);
 
   label = gtk_label_new (labeltext);
   free (labeltext);
-  free (labelkey);
-  free (desc);
 
   gtk_label_set_use_markup (GTK_LABEL(label), TRUE);
   gtk_label_set_line_wrap (GTK_LABEL(label), TRUE);
@@ -419,10 +402,10 @@ static GNode *create_item (const xine_cfg_entry_t *entry)
 static GNode *create_page (const char *key, size_t length)
 {
   pref_page_t *page = malloc (sizeof (pref_page_t));
-  page->notebook = (void *) 1; /* dummy value - filled in later */
+  page->notebook = GINT_TO_POINTER (1); /* dummy value - filled in later */
   page->page = page->table = NULL;
   page->prefix = malloc (length + 1);
-  sprintf (page->prefix, "%.*s", length, key);
+  sprintf (page->prefix, "%.*s", (int) length, key);
   page->label = strrchr (page->prefix, '.');
   if (page->label)
     ++page->label;
@@ -477,7 +460,7 @@ static gboolean unmix_mixed_page (GNode *node, gboolean *done)
   {
   case 0:
     /* hmm, odd... found a blank page - delete it */
-    printf ("gxine: prefs: eek, found a blank page '%s'\n", page->prefix);
+    logprintf ("gxine: prefs: eek, found a blank page '%s'\n", page->prefix);
     gtk_widget_destroy (page->notebook);
     free (page->prefix);
     free (page);
@@ -628,8 +611,6 @@ static void response_cb (GtkDialog *dbox, int response, gpointer data)
   gchar *fname;
   switch (response)
   {
-  case GTK_RESPONSE_REJECT:
-    
   case GTK_RESPONSE_ACCEPT:
     fname = g_strconcat(g_get_home_dir(), "/.gxine/config", NULL);
     xine_config_save (xine, fname);
@@ -645,7 +626,7 @@ static JSBool js_preferences_show (JSContext *cx, JSObject *obj, uintN argc,
 				   jsval *argv, jsval *rval)
 {
   /* se_t *se = (se_t *) JS_GetContextPrivate(cx); */
-  se_log_fncall ("preferences_show");
+  se_log_fncall_checkinit ("preferences_show");
   preferences_show ();
   return JS_TRUE;
 }
@@ -657,7 +638,7 @@ void preferences_show (void)
     gtk_widget_hide (prefs_dialog);
   } else {
     is_visible = TRUE;
-    gtk_widget_show (prefs_dialog);
+    window_show (prefs_dialog, NULL);
   }
 }
 
@@ -671,11 +652,10 @@ void preferences_init (void)
 				GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 				GTK_STOCK_CLOSE, GTK_RESPONSE_DELETE_EVENT,
 				NULL);
-  gtk_window_set_title (GTK_WINDOW (prefs_dialog), _("Preferences..."));
   gtk_window_set_default_size (GTK_WINDOW (prefs_dialog), 500, 150);
   hide_on_delete (prefs_dialog, &is_visible);
-  g_signal_connect (GTK_OBJECT(prefs_dialog), "response",
-		    GTK_SIGNAL_FUNC(response_cb), NULL);
+  g_signal_connect (G_OBJECT(prefs_dialog), "response",
+		    G_CALLBACK(response_cb), NULL);
 
   /* Make new tabbed box (notebook) */
   gtk_box_pack_start_defaults (GTK_BOX(GTK_DIALOG(prefs_dialog)->vbox),
@@ -702,3 +682,35 @@ void preferences_init (void)
   se_defun (gse, NULL, "preferences_show", js_preferences_show, 0, 0,
 	    SE_GROUP_DIALOGUE, NULL, NULL);
 }
+
+void preferences_update_entry (const xine_cfg_entry_t *entry)
+{
+  gpointer widget = g_datalist_get_data (&prefs_map, entry->key);
+
+  if (widget)
+    switch (entry->type) {
+    case XINE_CONFIG_TYPE_ENUM:
+      gtk_combo_box_set_active (widget, entry->num_value);
+      break;
+
+    case XINE_CONFIG_TYPE_STRING:
+      gtk_entry_set_text (widget, entry->str_value);
+      break;
+
+    case XINE_CONFIG_TYPE_RANGE: /* slider */
+      gtk_range_set_value (widget, entry->num_value);
+      break;
+
+    case XINE_CONFIG_TYPE_NUM:
+      gtk_spin_button_set_value (widget, entry->num_value);
+      break;
+
+    case XINE_CONFIG_TYPE_BOOL:
+      gtk_toggle_button_set_active (widget, entry->num_value == 1);
+      break;
+
+    default:;
+    }
+
+  xine_config_update_entry (xine, entry);
+}
