@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2001-2005 the xine project
+ * Copyright (C) 2001-2006 the xine project
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: preferences.h,v 1.6 2005/01/03 22:06:04 dsalt Exp $
+ * $Id: preferences.h,v 1.9 2006-02-21 19:06:12 dsalt Exp $
  *
  * Functions to stup and deal with a preferences dialog interfacing with
  * the xine config system.
@@ -28,5 +28,6 @@
 
 void preferences_init (void);
 void preferences_show (void);
+void preferences_update_entry (const xine_cfg_entry_t *);
 
 #endif
