@@ -13,10 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  *
- * $Id: settings.h,v 1.4 2005/01/03 22:06:04 dsalt Exp $
+ * $Id: settings.h,v 1.6 2006-02-28 18:10:18 dsalt Exp $
  *
  * settings window for gnome-xine
  */
@@ -24,5 +24,6 @@
 #define HAVE_SETTINGS_H
 
 void settings_init (void);
+void settings_clear (void);
 
 #endif
