@@ -13,9 +13,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: vis.c,v 1.8.2.1 2005/04/29 20:01:45 dsalt Exp $
+ * $Id: vis.c,v 1.16 2006/04/08 21:34:50 dsalt Exp $
  *
  * Visualisation wrapper code
  */
@@ -23,12 +23,13 @@
 #include "globals.h"
 
 #include <string.h>
-#include <pthread.h>
+
+#include "vis.h"
 
 #include "engine.h"
-#include "gtkvideo.h"
 #include "script_engine.h"
-#include "vis.h"
+#include "ui.h"
+#include "utils.h"
 
 gboolean vis_show (GtkVideo *this, xine_audio_port_t **audio_port)
 {
@@ -38,45 +39,44 @@ gboolean vis_show (GtkVideo *this, xine_audio_port_t **audio_port)
   return gtk_video_set_vis (this, audio_port, TRUE);
 }
 
-void vis_set (GtkVideo *this, const char *id, xine_audio_port_t **audio_p)
+void vis_cb (GtkRadioAction *action, gpointer data)
 {
-  int i;
-  gtk_video_select_vis (this, id, audio_p);
-  window_check_vis (TRUE);
-  for (i = 0; i < 2; ++i)
+  const char *const *pol =
+    xine_list_post_plugins_typed (xine, XINE_POST_TYPE_AUDIO_VISUALIZATION);
+  if (pol)
   {
-    GList *items = vis_menu[i]->children;
-    while (items)
-    {
-      GtkCheckMenuItem *item = items->data;
-      const char *data = g_object_get_data (G_OBJECT(item), "vis");
-      if (!data && (!id || !strcasecmp ("none", id)))
-	item->active = TRUE;
-      else if (data && id && !strcasecmp (data, id))
-	item->active = TRUE;
-      else
-	item->active = FALSE;
-      items = g_list_next (items);
-    }
+    int i = gtk_radio_action_get_current_value (action);
+    gtk_video_select_vis ((GtkVideo *)gtv, i ? pol[i - 1] : NULL, &audio_port);
+    window_check_vis (TRUE);
   }
 }
 
-static JSBool js_set_vis (JSContext *cx, JSObject *obj, uintN argc,
-			     jsval *argv, jsval *rval)
+void vis_set (const char *str)
 {
-  se_t     *se = (se_t *) JS_GetContextPrivate(cx);
-  JSString *str;
+  GSList *action;
+  foreach_glist (action, action_items.vis)
+  {
+    char *name;
+    g_object_get (action->data, "name", &name, NULL);
+    if (name[0] != '_' && !strcasecmp (str, "none"))
+      break;
+    g_object_get (action->data, "label", &name, NULL);
+    if (!strcasecmp (str, name))
+      break;
+  }
+  if (action)
+    gtk_action_activate (action->data);
+}
 
+static JSBool js_set_vis (JSContext *cx, JSObject *obj, uintN argc,
+			  jsval *argv, jsval *rval)
+{
   se_log_fncall ("js_set_vis");
-
   se_argc_check (1, "set_vis");
   se_arg_is_string (0, "set_vis");
 
-  str = JS_ValueToString (cx, argv[0]);
-  if (engine_mutex_trylock (se))
-    return JS_TRUE;
-  vis_set (GTK_VIDEO(gtv), JS_GetStringBytes (str), &audio_port);
-  pthread_mutex_unlock (&engine_lock);
+  JSString *str = JS_ValueToString (cx, argv[0]);
+  vis_set (JS_GetStringBytes (str));
 
   return JS_TRUE;
 }
@@ -87,5 +87,5 @@ void vis_init (void)
   se_defun (gse, NULL, "set_vis", js_set_vis, 0, 0,
 	    SE_GROUP_ENGINE, N_("string"), N_("visualisation name"));
   if (xine_config_lookup_entry (xine, "post_audio_plugin", &entry))
-    gtk_video_select_vis (GTK_VIDEO(gtv), entry.str_value, &audio_port);
+    gtk_video_select_vis ((GtkVideo *)gtv, entry.str_value, &audio_port);
 }
