@@ -13,9 +13,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  *
- * $Id: vis.h,v 1.3.2.1 2005/04/29 20:01:45 dsalt Exp $
+ * $Id: vis.h,v 1.7 2006-02-21 19:06:12 dsalt Exp $
  *
  * Visualisation wrapper code
  */
@@ -23,9 +23,14 @@
 #ifndef HAVE_VIS_H
 #define HAVE_VIS_H
 
+#include <gtk/gtkradioaction.h>
+
+#include "gtkvideo.h"
+
 #define vis_hide(V,A) gtk_video_set_vis ((V), (A), FALSE)
 gboolean vis_show (GtkVideo *, xine_audio_port_t **);
-void vis_set (GtkVideo *, const char *, xine_audio_port_t **);
+void vis_set (const char *);
+void vis_cb (GtkRadioAction *, gpointer);
 
 void vis_init (void);
 
